@@ -88,9 +88,9 @@ void ConjugationModeWidget::setQuestion(const QVariant &question)
 
     setNumberOfConjugationWidgets(data.personalPronouns.size());
     int i = 0;
-    for (QString pp : qAsConst(data.personalPronouns)) {
+    for (QString pp : std::as_const(data.personalPronouns)) {
         if (data.personalPronouns.size() == 1) {
-            pp += " (" + data.tense + ')';
+            pp += QStringLiteral(" (") + data.tense + QLatin1Char(')');
         }
         m_personWidgets.at(i)->person->setText(pp);
         m_personWidgets.at(i)->person->setFont(m_solutionFont);
